@@ -1,4 +1,4 @@
-from .logic import *
+from logic import *
 
 if __name__ == '__main__':
     # Защита чтобы ide не убирал импорт
